@@ -27,7 +27,7 @@
 */
 
 #include <aconf.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include "eel-vfs-extensions.h"
 
 #define EEL_OMIT_SELF_CHECK
