@@ -506,7 +506,9 @@ gpdf_bookmarks_view_update_bkvisual (GtkTreeModel *model,
 				  &an_item_value);
 	anItem = (OutlineItem *) g_value_get_pointer ((const GValue *)&an_item_value);
 
-	if (anItem->getAction ()->getKind () == actionGoTo)
+	/* anItem is NULL if no action was associated with the node,
+	 * see also gpdf_bookmarks_view_flat_recurse_outlines */
+	if (anItem && anItem->getAction ()->getKind () == actionGoTo)
 	{
 		/* Get this bookmark page nr */
 		gtk_tree_model_get_value (model,
@@ -1153,7 +1155,7 @@ gpdf_bookmarks_view_populate_idle (GPdfBookmarksView *bookmarks_view)
 		GdkWindow *parent_window;
 
 		display = gtk_widget_get_display (priv->treeview);
-		parent_window = gtk_widget_get_parent_window (priv->treeview);
+		parent_window = GTK_WIDGET (priv->treeview)->window;
 		if (GDK_IS_WINDOW (parent_window))
 			gdk_window_set_cursor (parent_window, NULL); 
 		gdk_flush();
@@ -1171,7 +1173,7 @@ gpdf_bookmarks_view_populate_idle (GPdfBookmarksView *bookmarks_view)
 		/* Set watch cursor while view not ready */
 		display = gtk_widget_get_display (priv->treeview);
 		cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
-		parent_window = gtk_widget_get_parent_window (priv->treeview);
+		parent_window = GTK_WIDGET (priv->treeview)->window;
 		if (GDK_IS_WINDOW (parent_window))
 			gdk_window_set_cursor (parent_window, cursor); 
 		gdk_cursor_unref (cursor);
@@ -1182,6 +1184,12 @@ gpdf_bookmarks_view_populate_idle (GPdfBookmarksView *bookmarks_view)
 	return (!priv->generation_terminated);
 }
 
+static void
+disconnected_handler (gpointer control, gpointer data)
+{
+	g_source_remove (GPOINTER_TO_UINT (data));
+}
+
 void
 gpdf_bookmarks_view_set_pdf_doc (GPdfBookmarksView *bookmarks_view,
 				 PDFDoc *pdf_doc)
@@ -1201,9 +1209,9 @@ gpdf_bookmarks_view_set_pdf_doc (GPdfBookmarksView *bookmarks_view,
 		priv->idle_id = g_idle_add ((GSourceFunc)gpdf_bookmarks_view_populate_idle,
 					    bookmarks_view);
 
-		g_signal_connect_swapped (G_OBJECT (priv->parent), "disconnected", 
-					  G_CALLBACK (g_source_remove),
-					  (gpointer)priv->idle_id);
+		g_signal_connect (G_OBJECT (priv->parent), "disconnected", 
+				  G_CALLBACK (disconnected_handler),
+				  GUINT_TO_POINTER (priv->idle_id));
 	}
 }
 
