@@ -23,9 +23,9 @@
 
 #include <aconf.h>
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
 #include "gpdf-util.h"
 #include "pdf-properties-display.h"
